
# Atelier 3 : Décrire et documenter ses données avec des métadonnées standardisées - animé par Martine Barale (Cirad)

![licence_cc_by](by.png)

_Ce document est mis à disposition selon les termes de la [Licence Creative Commons Attribution 4.0 International](http://creativecommons.org/licenses/by/4.0/). Auteur : Frédérique Flamerie / Contributeurs : Julien Baudry et Marie-Aimée Berthelot_


Cet atelier a rassemblé seize participants, majoritairement chercheurs ou professionnels de l'IST, d'horizons disciplinaires divers (histoire, médecine, géosciences, etc.), autour du programme suivant :

* Définition et usage des métadonnées pour les données de recherche
* Aperçu sur les standards de métadonnées : comment choisir un modèle de métadonnées ? comment décrire un jeu de données ?
* Exemples pratiques :
  * Évaluer la description d’un jeu de données déposé dans un entrepôt.
  * A partir de cas apportés par la formatrice, décrire des données relevant (i) d’une discipline sans standard de métadonnées et (ii) d’une discipline ayant un standard de métadonnées.

## Présentation

Le support de présentation est disponible à l'adresse <https://doi.org/10.5281/zenodo.1256735>.

M. Barale a structuré sa présentation autour des points suivants.

* Pourquoi des données de recherche ouvertes ?
* Quelles données sont-elles concernées ?
* Où agréger ses données de recherche ?
* Comment assurer la compréhension et la réutilisation des données ?
* Comment choisir un standard de métadonnées ?

Une fois défini le périmètre des données de recherche et posé les enjeux liés à leur ouverture, la question de leur préparation en vue de leur publication permet d'aborder une notion centrale, celle du jeu de données (_dataset_). Rendre publiques ses données implique en effet de les constituer en jeux, _i. e._ en ensembles organisés et cohérents, qui puissent être décrits par des métadonnées communes. La constitution des jeux de données suppose une réflexion à la fois sur la sélection des données à inclure et sur la logique d'organisation à appliquer. A cet égard, la nécessité de l’anticipation et d’une réflexion au sein de l’équipe projet est soulignée. Cette prise en compte en amont est aussi importante pour organiser le travail de description des données dès le début puis tout au long du projet de recherche. Même si la saisie des métadonnées intervient souvent en dernier lieu, elles doivent être, dans la mesure du possible, pensées dès le départ et non face au formulaire de dépôt dans un entrepôt.

Comment produire des métadonnées de qualité ? Même si tous les entrepôts n'exigent pas les mêmes champs de métadonnées, il faut toujours compléter _a minima_ des métadonnées de "base". Certains établissements donnent des recommandations en ce sens : auteur et leur affiliation, date de création, mots-clés, etc. Des recommandations en termes de formats de fichier peuvent également être formulées.

L’accent est mis sur les noms des fichiers : ils doivent être le plus explicite possible et respecter systématiquement une convention à définir pour le projet (par exemple : projet_type de données_date). Il convient d’éviter les espaces et les caractères spéciaux.

De plus, si la production de métadonnées standardisées est essentielle pour permettre la compréhension et la réutilisation des données, l'importance de la documentation associée (fichier "lisez-moi" ou "_README_", dictionnaire de données, etc.) est rappelée. Cette documentation peut être intégrée en tant que fichier à part entière (au format txt) dans le jeu de données.

Quel standard de métadonnées choisir ? Le Dublin Core est le standard générique, mais bien souvent il ne suffit pas. Le choix d'un standard de métadonnées doit tenir compte de critères tels que le type de données à décrire, le domaine scientifique, les pratiques au sein de sa communauté, l'entrepôt de dépôt. Des outils tels que les suivants permettent notamment d'identifier les standards de métadonnées spécifiques à une discipline :

* le répertoire [re3data.org](https://www.re3data.org/browse/by-subject/) des entrepôts de données,
* les listes du [Digital Curation Centre](http://www.dcc.ac.uk/resources/metadata-standards).

## Exercices pratiques

### Exercice 1 : Evaluer la description d'un jeu de données
Les jeux de données à évaluer sont regroupés en 4 thématiques  : histoire, sciences sociales et économiques, science de la terre et de l'univers, science de la vie. L'exercice consiste à évaluer la qualité des métadonnées proposées par le déposant : permettent-elles de recontextualiser correctement les données et de les retrouver facilement ?

Cet exercice montre la diversité des pratiques, du jeu de données déposé pour un usage juste personnel sans réutilisation possible par d'autres (archivage seulement) à des jeux de donnés très bien décrits, en passant par des jeux de données partiellement décrits (jeu de données bien décrit mais fichiers mal nommés, etc.).

Il illustre surtout l'importance de métadonnées riches et d'une documentation complète pour assurer l'intelligibilité et la réutilisabilité des données.

#### Retours sur quelques exemples
* Ex 1 thématique histoire - <https://zenodo.org/record/1159078> : l'absence de mots-clés, de titre significatif et de description limite les possibilités de retrouver le jeu de données (_discoverability_).
* Ex 2 thématique histoire - <https://zenodo.org/record/835588> : le titre et les mots-clés sont descriptifs et significatifs. En revanche, le manque d'une documentation plus précise ne permet pas une compréhension immédiate du jeu de données ni de son organisation (plus de 300 fichiers dont le schéma de nommage n’est pas entièrement explicité).
* Ex 4 thématique histoire - <https://zenodo.org/record/1183367> : l'absence tant de description que de documentation associée rend difficile à la fois la compréhension et la réutilisation des données. L'entrepôt semble avoir été utilisé à des fins d'archivage uniquement et non pour favoriser des réutilisations potentielles.
* Ex 2 thématique sciences sociales et économiques - <https://zenodo.org/record/1174366> : ce dépôt est un bon exemple à la fois de description et de documentation des données ; le lien à la publication associée (poster) est bien mentionné. Un fichier readme.txt est présent.
* Ex 1 thématique sciences de la vie, médecine, agronomie - <http://doi.org/10.5281/zenodo.1237738> : ce dépôt constitue un bon exemple de description détaillée, intégrant une référence au projet de recherche, la mention d'une personne contact, des mots-clés et un dictionnaire de données. Le fichier de données Excel comporte également un bref résumé descriptif (feuille _Summary_).
* Ex 2 thématique sciences de la vie, médecine, agronomie - <http://doi.org/10.5281/zenodo.12347> : les éléments descriptifs sont insuffisants : le titre n'est pas informatif, la description réduite à une ligne et  les mots-clés absents ; le fichier de données au format Excel est dépourvu de dictionnaire de données.
* Ex 1 thématique sciences de la terre et de l'univers - <https://zenodo.org/record/1220566> : la description (titre, résumé) est trop imprécise pour pouvoir contextualiser le jeu de données ; l'absence de documentation associée ne permet pas une compréhension immédiate du jeu de données ni de son organisation.
* Ex 2 thématique sciences de la terre et de l'univers - <https://zenodo.org/record/12873> : ce jeu de données constitue le _supplementary material_ d'un article, et le lien avec l'article est bien mentionné dans les métadonnées. La citation donnée par les contributeurs est celle de l’article et non du jeu de données  lui-même (voir _infra_).

> When using the data please cite as follows: Petry, S and Beyer, K; Scaling unreinforced masonry for reduced-scale seismic testing. Bulletin of Earthquake Engineering (2014), 12(6):2557–2581, DOI: 10.1007/s10518-014-9605-1

### Exercice 2 : Déposer un jeu de données dans le site de démonstration du [Dataverse d'Harvard](https://demo.dataverse.org)
L'exercice permet de mettre en évidence des points de vigilance dans la procédure de dépôt. Cette procédure peut être complétée en plusieurs temps, l'interface disposant d'une fonction de sauvegarde d'un dépôt en cours ; la publication intervient seulement après la validation du dépôt par le contributeur.

* Il convient de bien réfléchir à la formulation et à la saisie des éléments tels que l'affiliation, la date (utiliser un format normalisé ISO YYYY-MM-DD, etc.), etc.
* Champ _KeyWord_ : les mots-clés sont choisis librement, mais il est recommandé d'utiliser un vocabulaire de référence de sa discipline (Ex le CIRAD se sert d'AGROVOC) pour optimiser l'interrogation et l'interopérabilité.
* Téléchargement d'un fichier : il est possible de décrire chaque fichier déposé.
* Niveaux de description : il est possible d'éditer les métadonnées _a posteriori_ pour les compléter, ainsi que de choisir un autre standard de métadonnées que celui proposé par défaut pour affiner la description du _dataset_. L'interface propose en effet deux niveaux de métadonnées : un premier ensemble "générique" de métadonnées au format Dublin Core, puis un second ensemble de métadonnées basé sur plusieurs standards disciplinaires   : DDI pour les données d’enquête, ISA-Tab pour les données en sciences de la vie, etc.

## Questions des participants à l'atelier

### Est-il nécessaire de remplir tous les champs de métadonnées?
Chaque entrepôt détermine les champs qu'il rend obligatoires et facultatifs. Il s'agit de trouver un équilibre :  assurer un niveau de description suffisamment détaillé des jeux de données et ne pas décourager les contributions par un formulaire de dépôt exigeant un travail de saisie trop important.

### Des métadonnées sont-elles communes à tous les standards?
On retrouve en général tous les éléments du Dublin Core.

### Peut-on retirer un jeu de données?
Si le retrait ou la suppression d'un dépôt n'est pas possible, le versionnage, _i. e._ le dépôt de versions ultérieures, l'est.

### Y a-t-il une taille limite de fichiers?
Cela dépend des entrepôts. On peut citer la limite de 50 Go par _dataset_ appliquée par Zenodo.

## Questions des participants à la journée - séance plénière de l'après-midi
### Faut-il connaître le Dublin Core?
Les interfaces de saisie intègrent le Dublin Core : il suffit par exemple de compléter le formulaire de dépôt dans un entrepôt de données pour générer des métadonnées en Dublin Core.

### Qu'est-ce qu'un fichier _README_? En quoi se distinguent-ils des métadonnées?
Le fichier _README_ permet de décrire les données, mais à la différence des métadonnées il n'est pas normalisé ni structuré en champs. Il sert à fournir tous les éléments sur le contenu des fichiers, les formats, etc.  permettant de comprendre et de réutiliser les  données.

_Ajout post-atelier_

Des exemples et modèles de fichier README sont notamment fournis par l'Université de Cornell et par 4TU.ResearchData.

4TU Centre for Research Data. (2017, décembre). Guidelines for creating a README file. Repéré à http://researchdata.4tu.nl/fileadmin/editor_upload/pdf/README/Guidelines_for_creating_a_README_file.pdf

Cornell Research Data Management Service Group. (n.d.). Guide to writing « readme » style metadata. _Research Data Management Service Group_. Repéré à https://data.research.cornell.edu/content/readme
